@@ -9,5 +9,9 @@ class TestView(FormView):
     template_name = 'test_app/test_view.html'
     form_class = DummyModelForm
 
+    def form_valid(self, form):
+        form.save()
+        return super(TestView, self).form_valid(form)
+
     def get_success_url(self):
         return reverse('user_tags_test_view')
